"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.common_config.env_pb2
import prodvana.proto.prodvana.common_config.kubernetes_config_pb2
import prodvana.proto.prodvana.common_config.parameters_pb2
import prodvana.proto.prodvana.common_config.rollback_pb2
import prodvana.proto.prodvana.common_config.task_pb2
import prodvana.proto.prodvana.labels.labels_pb2
import prodvana.proto.prodvana.runtimes.extensions.fetch_pb2
import prodvana.proto.prodvana.runtimes.runtimes_config_pb2
import prodvana.proto.prodvana.volumes.volumes_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ClusterType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ClusterTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ClusterType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _ClusterType.ValueType  # 0
    K8S: _ClusterType.ValueType  # 1
    ECS: _ClusterType.ValueType  # 2
    """TODO(naphat) remove, this is legacy ecs implementation not based on runtime extension"""
    FAKE: _ClusterType.ValueType  # 3
    EXTENSION: _ClusterType.ValueType  # 4
    TERRAFORM_RUNNER: _ClusterType.ValueType  # 5
    PULUMI_RUNNER: _ClusterType.ValueType  # 6
    AWS_ECS: _ClusterType.ValueType  # 7
    GOOGLE_CLOUD_RUN: _ClusterType.ValueType  # 8

class ClusterType(_ClusterType, metaclass=_ClusterTypeEnumTypeWrapper): ...

UNKNOWN: ClusterType.ValueType  # 0
K8S: ClusterType.ValueType  # 1
ECS: ClusterType.ValueType  # 2
"""TODO(naphat) remove, this is legacy ecs implementation not based on runtime extension"""
FAKE: ClusterType.ValueType  # 3
EXTENSION: ClusterType.ValueType  # 4
TERRAFORM_RUNNER: ClusterType.ValueType  # 5
PULUMI_RUNNER: ClusterType.ValueType  # 6
AWS_ECS: ClusterType.ValueType  # 7
GOOGLE_CLOUD_RUN: ClusterType.ValueType  # 8
global___ClusterType = ClusterType

class _ExtensionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExtensionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExtensionType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    GENERIC: _ExtensionType.ValueType  # 0
    TERRAFORM: _ExtensionType.ValueType  # 1
    PULUMI: _ExtensionType.ValueType  # 2
    AWS_ECS_EXTENSION: _ExtensionType.ValueType  # 3
    GOOGLE_CLOUD_RUN_EXTENSION: _ExtensionType.ValueType  # 4

class ExtensionType(_ExtensionType, metaclass=_ExtensionTypeEnumTypeWrapper): ...

GENERIC: ExtensionType.ValueType  # 0
TERRAFORM: ExtensionType.ValueType  # 1
PULUMI: ExtensionType.ValueType  # 2
AWS_ECS_EXTENSION: ExtensionType.ValueType  # 3
GOOGLE_CLOUD_RUN_EXTENSION: ExtensionType.ValueType  # 4
global___ExtensionType = ExtensionType

class ClusterAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ECSAuth(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ACCESS_KEY_FIELD_NUMBER: builtins.int
        SECRET_KEY_FIELD_NUMBER: builtins.int
        REGION_FIELD_NUMBER: builtins.int
        ASSUME_ROLE_ARN_FIELD_NUMBER: builtins.int
        CLUSTER_ARN_FIELD_NUMBER: builtins.int
        access_key: builtins.str
        secret_key: builtins.str
        region: builtins.str
        assume_role_arn: builtins.str
        cluster_arn: builtins.str
        def __init__(
            self,
            *,
            access_key: builtins.str = ...,
            secret_key: builtins.str = ...,
            region: builtins.str = ...,
            assume_role_arn: builtins.str = ...,
            cluster_arn: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["access_key", b"access_key", "assume_role_arn", b"assume_role_arn", "cluster_arn", b"cluster_arn", "region", b"region", "secret_key", b"secret_key"]) -> None: ...

    class K8sAuth(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class AgentEnvEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            value: builtins.str
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

        AGENT_ENV_FIELD_NUMBER: builtins.int
        AGENT_EXTERNALLY_MANAGED_FIELD_NUMBER: builtins.int
        @property
        def agent_env(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
        agent_externally_managed: builtins.bool
        """The Prodvana agent lifecycle is handled by the user -- Prodvana will not install or update the agent."""
        def __init__(
            self,
            *,
            agent_env: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
            agent_externally_managed: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["agent_env", b"agent_env", "agent_externally_managed", b"agent_externally_managed"]) -> None: ...

    ECS_FIELD_NUMBER: builtins.int
    K8S_FIELD_NUMBER: builtins.int
    @property
    def ecs(self) -> global___ClusterAuth.ECSAuth: ...
    @property
    def k8s(self) -> global___ClusterAuth.K8sAuth: ...
    def __init__(
        self,
        *,
        ecs: global___ClusterAuth.ECSAuth | None = ...,
        k8s: global___ClusterAuth.K8sAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_oneof", b"auth_oneof", "ecs", b"ecs", "k8s", b"k8s"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_oneof", b"auth_oneof", "ecs", b"ecs", "k8s", b"k8s"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth_oneof", b"auth_oneof"]) -> typing_extensions.Literal["ecs", "k8s"] | None: ...

global___ClusterAuth = ClusterAuth

class Cluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    LAST_HEARTBEAT_TIMESTAMP_FIELD_NUMBER: builtins.int
    name: builtins.str
    cluster_id: builtins.str
    @property
    def auth(self) -> global___ClusterAuth: ...
    type: global___ClusterType.ValueType
    @property
    def config(self) -> global___ClusterConfig: ...
    @property
    def last_heartbeat_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        auth: global___ClusterAuth | None = ...,
        type: global___ClusterType.ValueType = ...,
        config: global___ClusterConfig | None = ...,
        last_heartbeat_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "config", b"config", "last_heartbeat_timestamp", b"last_heartbeat_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "cluster_id", b"cluster_id", "config", b"config", "last_heartbeat_timestamp", b"last_heartbeat_timestamp", "name", b"name", "type", b"type"]) -> None: ...

global___Cluster = Cluster

class FakeClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class CrashingProgramPatterns(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IMAGE_REGEX_FIELD_NUMBER: builtins.int
        CMD_REGEX_FIELD_NUMBER: builtins.int
        LOG_OUTPUT_FIELD_NUMBER: builtins.int
        image_regex: builtins.str
        cmd_regex: builtins.str
        log_output: builtins.str
        def __init__(
            self,
            *,
            image_regex: builtins.str = ...,
            cmd_regex: builtins.str = ...,
            log_output: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["cmd_regex", b"cmd_regex", "image_regex", b"image_regex", "log_output", b"log_output"]) -> None: ...

    CRASHING_PROGRAMS_FIELD_NUMBER: builtins.int
    @property
    def crashing_programs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FakeClusterConfig.CrashingProgramPatterns]: ...
    def __init__(
        self,
        *,
        crashing_programs: collections.abc.Iterable[global___FakeClusterConfig.CrashingProgramPatterns] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["crashing_programs", b"crashing_programs"]) -> None: ...

global___FakeClusterConfig = FakeClusterConfig

class RetryPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_INTERVAL_FIELD_NUMBER: builtins.int
    MAX_INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def base_interval(self) -> google.protobuf.duration_pb2.Duration: ...
    @property
    def max_interval(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        base_interval: google.protobuf.duration_pb2.Duration | None = ...,
        max_interval: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_interval", b"base_interval", "max_interval", b"max_interval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_interval", b"base_interval", "max_interval", b"max_interval"]) -> None: ...

global___RetryPolicy = RetryPolicy

class ExtensionFetchCommand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TASK_CONFIG_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    POLL_INTERVAL_FIELD_NUMBER: builtins.int
    STEADY_STATE_POLL_INTERVAL_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    FETCH_MODE_FIELD_NUMBER: builtins.int
    @property
    def task_config(self) -> prodvana.proto.prodvana.common_config.task_pb2.TaskConfig: ...
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def poll_interval(self) -> google.protobuf.duration_pb2.Duration:
        """customize intervals instead of using Prodvana default
        only used for fetch
        how often to run command after it succeeds
        """
    @property
    def steady_state_poll_interval(self) -> google.protobuf.duration_pb2.Duration:
        """how often to fetch when in steady state (after the extension has converged)"""
    @property
    def timeout(self) -> google.protobuf.duration_pb2.Duration:
        """deprecated, not used"""
    @property
    def retry_policy(self) -> global___RetryPolicy:
        """retry policy for unexpected failures (this means exits other than 0 or 2 when fetch_mode = EXIT_CODE, or other than 0 for STRUCTURED_OUTPUT).
        if not set, regular, non-steady-state poll interval is used for fetches.
        """
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """optional env variables to inject and override from exec_config"""
    fetch_mode: prodvana.proto.prodvana.runtimes.extensions.fetch_pb2.FetchMode.ValueType
    """how to interpret the output of the command"""
    def __init__(
        self,
        *,
        task_config: prodvana.proto.prodvana.common_config.task_pb2.TaskConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        poll_interval: google.protobuf.duration_pb2.Duration | None = ...,
        steady_state_poll_interval: google.protobuf.duration_pb2.Duration | None = ...,
        timeout: google.protobuf.duration_pb2.Duration | None = ...,
        retry_policy: global___RetryPolicy | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        fetch_mode: prodvana.proto.prodvana.runtimes.extensions.fetch_pb2.FetchMode.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "poll_interval", b"poll_interval", "retry_policy", b"retry_policy", "steady_state_poll_interval", b"steady_state_poll_interval", "task_config", b"task_config", "timeout", b"timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["env", b"env", "exec_config", b"exec_config", "fetch_mode", b"fetch_mode", "kubernetes_config", b"kubernetes_config", "poll_interval", b"poll_interval", "retry_policy", b"retry_policy", "steady_state_poll_interval", b"steady_state_poll_interval", "task_config", b"task_config", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["exec_config", b"exec_config"]) -> typing_extensions.Literal["task_config", "kubernetes_config"] | None: ...

global___ExtensionFetchCommand = ExtensionFetchCommand

class ExtensionGetInfoCommand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TASK_CONFIG_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    POLL_INTERVAL_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    TEST_ONLY_DO_NOT_REQUIRE_PVN_WRAPPER_FIELD_NUMBER: builtins.int
    @property
    def task_config(self) -> prodvana.proto.prodvana.common_config.task_pb2.TaskConfig: ...
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def poll_interval(self) -> google.protobuf.duration_pb2.Duration:
        """customize intervals instead of using Prodvana default
        defaults to 5 minutes
        """
    @property
    def retry_policy(self) -> global___RetryPolicy:
        """retry policy for unexpected failures.
        defaults to fast retrying after 30s then backing off to 10 minutes
        """
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """optional env variables to inject and override from exec_config"""
    test_only_do_not_require_pvn_wrapper: builtins.bool
    """exposed for internal testing. do not set"""
    def __init__(
        self,
        *,
        task_config: prodvana.proto.prodvana.common_config.task_pb2.TaskConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        poll_interval: google.protobuf.duration_pb2.Duration | None = ...,
        retry_policy: global___RetryPolicy | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        test_only_do_not_require_pvn_wrapper: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "poll_interval", b"poll_interval", "retry_policy", b"retry_policy", "task_config", b"task_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["env", b"env", "exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "poll_interval", b"poll_interval", "retry_policy", b"retry_policy", "task_config", b"task_config", "test_only_do_not_require_pvn_wrapper", b"test_only_do_not_require_pvn_wrapper"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["exec_config", b"exec_config"]) -> typing_extensions.Literal["task_config", "kubernetes_config"] | None: ...

global___ExtensionGetInfoCommand = ExtensionGetInfoCommand

class ExtensionApplyCommand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TASK_CONFIG_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    RETRYABLE_EXIT_CODES_FIELD_NUMBER: builtins.int
    @property
    def task_config(self) -> prodvana.proto.prodvana.common_config.task_pb2.TaskConfig: ...
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def timeout(self) -> google.protobuf.duration_pb2.Duration:
        """deprecated, not used"""
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """optional env variables to inject and override from exec_config"""
    @property
    def retry_policy(self) -> global___RetryPolicy:
        """used in conjunction with retryable_exit_codes, defaults to the convergence grace period"""
    @property
    def retryable_exit_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """if set and the apply command returns these exit codes, retry the command without marking the result as failing."""
    def __init__(
        self,
        *,
        task_config: prodvana.proto.prodvana.common_config.task_pb2.TaskConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        timeout: google.protobuf.duration_pb2.Duration | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        retry_policy: global___RetryPolicy | None = ...,
        retryable_exit_codes: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "retry_policy", b"retry_policy", "task_config", b"task_config", "timeout", b"timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["env", b"env", "exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "retry_policy", b"retry_policy", "retryable_exit_codes", b"retryable_exit_codes", "task_config", b"task_config", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["exec_config", b"exec_config"]) -> typing_extensions.Literal["task_config", "kubernetes_config"] | None: ...

global___ExtensionApplyCommand = ExtensionApplyCommand

class ExtensionClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLY_FIELD_NUMBER: builtins.int
    FETCH_FIELD_NUMBER: builtins.int
    DEBUG_FIELD_NUMBER: builtins.int
    GET_INFO_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    PROXY_RUNTIME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    REQUIRE_APPROVAL_BEFORE_APPLY_FIELD_NUMBER: builtins.int
    CONVERGENCE_GRACE_PERIOD_FIELD_NUMBER: builtins.int
    @property
    def apply(self) -> global___ExtensionApplyCommand: ...
    @property
    def fetch(self) -> global___ExtensionFetchCommand: ...
    @property
    def debug(self) -> global___ExtensionGetInfoCommand:
        """deprecated, set this as get_info instead"""
    @property
    def get_info(self) -> global___ExtensionGetInfoCommand: ...
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition]: ...
    @property
    def proxy_runtime(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    type: global___ExtensionType.ValueType
    require_approval_before_apply: builtins.bool
    """Apply is potentially dangerous - require approval before each apply"""
    @property
    def convergence_grace_period(self) -> google.protobuf.duration_pb2.Duration:
        """How long after apply ran the first time should it be restarted if the service still has not converged.
        This duration is computed from the *start* of apply run.
        Defaults to 10m.
        next tag: 10
        """
    def __init__(
        self,
        *,
        apply: global___ExtensionApplyCommand | None = ...,
        fetch: global___ExtensionFetchCommand | None = ...,
        debug: global___ExtensionGetInfoCommand | None = ...,
        get_info: global___ExtensionGetInfoCommand | None = ...,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition] | None = ...,
        proxy_runtime: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        type: global___ExtensionType.ValueType = ...,
        require_approval_before_apply: builtins.bool = ...,
        convergence_grace_period: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["apply", b"apply", "convergence_grace_period", b"convergence_grace_period", "debug", b"debug", "fetch", b"fetch", "get_info", b"get_info", "proxy_runtime", b"proxy_runtime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apply", b"apply", "convergence_grace_period", b"convergence_grace_period", "debug", b"debug", "fetch", b"fetch", "get_info", b"get_info", "parameters", b"parameters", "proxy_runtime", b"proxy_runtime", "require_approval_before_apply", b"require_approval_before_apply", "type", b"type"]) -> None: ...

global___ExtensionClusterConfig = ExtensionClusterConfig

class CompiledExtensionCommand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class CompiledExtensionCommandExec(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TASK_CONFIG_FIELD_NUMBER: builtins.int
        KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
        @property
        def task_config(self) -> prodvana.proto.prodvana.common_config.task_pb2.TaskConfig: ...
        @property
        def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
        def __init__(
            self,
            *,
            task_config: prodvana.proto.prodvana.common_config.task_pb2.TaskConfig | None = ...,
            kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "task_config", b"task_config"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "task_config", b"task_config"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["exec_config", b"exec_config"]) -> typing_extensions.Literal["task_config", "kubernetes_config"] | None: ...

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_PREFIX_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    RUNTIME_EXECUTION_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    name_prefix: builtins.str
    @property
    def command(self) -> global___CompiledExtensionCommand.CompiledExtensionCommandExec:
        """weird nesting for compatibility reasons, from before fetch and apply definitions were split"""
    @property
    def runtime_execution(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]: ...
    def __init__(
        self,
        *,
        name_prefix: builtins.str = ...,
        command: global___CompiledExtensionCommand.CompiledExtensionCommandExec | None = ...,
        runtime_execution: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["command", b"command", "runtime_execution", b"runtime_execution"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "env", b"env", "name_prefix", b"name_prefix", "runtime_execution", b"runtime_execution"]) -> None: ...

global___CompiledExtensionCommand = CompiledExtensionCommand

class IacRunnerCommand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CMD_FIELD_NUMBER: builtins.int
    cmd: builtins.str
    def __init__(
        self,
        *,
        cmd: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cmd", b"cmd"]) -> None: ...

global___IacRunnerCommand = IacRunnerCommand

class TerraformRunnerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PROXY_RUNTIME_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    PRE_RUN_FIELD_NUMBER: builtins.int
    POLL_INTERVAL_FIELD_NUMBER: builtins.int
    STEADY_STATE_POLL_INTERVAL_FIELD_NUMBER: builtins.int
    REQUIRE_APPROVAL_BEFORE_APPLY_FIELD_NUMBER: builtins.int
    CONVERGENCE_GRACE_PERIOD_FIELD_NUMBER: builtins.int
    FETCH_RETRY_POLICY_FIELD_NUMBER: builtins.int
    APPLY_RETRY_POLICY_FIELD_NUMBER: builtins.int
    DISABLE_DRIFT_DETECTION_FIELD_NUMBER: builtins.int
    @property
    def proxy_runtime(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """optional env variables to pass to terraform commands, can be useful for passing secrets"""
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.volumes.volumes_pb2.Volume]:
        """optional volumes to mount into terraform containers"""
    @property
    def pre_run(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IacRunnerCommand]:
        """commands that must run before terraform can run, e.g. gcloud auth login"""
    @property
    def poll_interval(self) -> google.protobuf.duration_pb2.Duration:
        """Poll interval for terraform plan when not converged, defaults to 5 minutes. Polling takes a lock on terraform state file, so increase this if you run terraform plan locally often."""
    @property
    def steady_state_poll_interval(self) -> google.protobuf.duration_pb2.Duration:
        """Poll interval for terraform plan in steady state (after it has converged), defaults to 1 hour. During steady state, polling is used for drift detection.
        This is the min duration of time for which drift not being detected is OK.
        """
    require_approval_before_apply: builtins.bool
    """Require approval before every apply operation - this is on top of any release channel-level approvals."""
    @property
    def convergence_grace_period(self) -> google.protobuf.duration_pb2.Duration: ...
    @property
    def fetch_retry_policy(self) -> global___RetryPolicy:
        """override default retry policy. Default is min = 1m, max = 15m."""
    @property
    def apply_retry_policy(self) -> global___RetryPolicy:
        """override apply retry policy. Default is min = 30s, max = 5m."""
    disable_drift_detection: builtins.bool
    """Skip drift detection. This is useful for faster convergence on updates, but can lead to drift going undetected.
    When enabled, steady state polling is turned off.
    NOTE: Only supported in Pulumi today.
    next tag: 12
    """
    def __init__(
        self,
        *,
        proxy_runtime: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        volumes: collections.abc.Iterable[prodvana.proto.prodvana.volumes.volumes_pb2.Volume] | None = ...,
        pre_run: collections.abc.Iterable[global___IacRunnerCommand] | None = ...,
        poll_interval: google.protobuf.duration_pb2.Duration | None = ...,
        steady_state_poll_interval: google.protobuf.duration_pb2.Duration | None = ...,
        require_approval_before_apply: builtins.bool = ...,
        convergence_grace_period: google.protobuf.duration_pb2.Duration | None = ...,
        fetch_retry_policy: global___RetryPolicy | None = ...,
        apply_retry_policy: global___RetryPolicy | None = ...,
        disable_drift_detection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["apply_retry_policy", b"apply_retry_policy", "convergence_grace_period", b"convergence_grace_period", "fetch_retry_policy", b"fetch_retry_policy", "poll_interval", b"poll_interval", "proxy_runtime", b"proxy_runtime", "steady_state_poll_interval", b"steady_state_poll_interval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apply_retry_policy", b"apply_retry_policy", "convergence_grace_period", b"convergence_grace_period", "disable_drift_detection", b"disable_drift_detection", "env", b"env", "fetch_retry_policy", b"fetch_retry_policy", "poll_interval", b"poll_interval", "pre_run", b"pre_run", "proxy_runtime", b"proxy_runtime", "require_approval_before_apply", b"require_approval_before_apply", "steady_state_poll_interval", b"steady_state_poll_interval", "volumes", b"volumes"]) -> None: ...

global___TerraformRunnerConfig = TerraformRunnerConfig

class GKEClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_NAME_FIELD_NUMBER: builtins.int
    CLUSTER_LOCATION_FIELD_NUMBER: builtins.int
    CLUSTER_NAME_FIELD_NUMBER: builtins.int
    project_name: builtins.str
    cluster_location: builtins.str
    cluster_name: builtins.str
    def __init__(
        self,
        *,
        project_name: builtins.str = ...,
        cluster_location: builtins.str = ...,
        cluster_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_location", b"cluster_location", "cluster_name", b"cluster_name", "project_name", b"project_name"]) -> None: ...

global___GKEClusterMetadata = GKEClusterMetadata

class ClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GKE_FIELD_NUMBER: builtins.int
    @property
    def gke(self) -> global___GKEClusterMetadata: ...
    def __init__(
        self,
        *,
        gke: global___GKEClusterMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_metadata", b"cluster_metadata", "gke", b"gke"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_metadata", b"cluster_metadata", "gke", b"gke"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["cluster_metadata", b"cluster_metadata"]) -> typing_extensions.Literal["gke"] | None: ...

global___ClusterMetadata = ClusterMetadata

class AwsEcsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class AccessKey(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        AWS_ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
        AWS_SECRET_ACCESS_KEY_FIELD_NUMBER: builtins.int
        aws_access_key_id: builtins.str
        @property
        def aws_secret_access_key(self) -> prodvana.proto.prodvana.common_config.env_pb2.SecretReferenceValue: ...
        def __init__(
            self,
            *,
            aws_access_key_id: builtins.str = ...,
            aws_secret_access_key: prodvana.proto.prodvana.common_config.env_pb2.SecretReferenceValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["aws_secret_access_key", b"aws_secret_access_key"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["aws_access_key_id", b"aws_access_key_id", "aws_secret_access_key", b"aws_secret_access_key"]) -> None: ...

    PROXY_RUNTIME_FIELD_NUMBER: builtins.int
    ACCESS_KEY_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ECS_CLUSTER_FIELD_NUMBER: builtins.int
    @property
    def proxy_runtime(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    @property
    def access_key(self) -> global___AwsEcsConfig.AccessKey:
        """TODO(naphat) assumeRole support"""
    region: builtins.str
    ecs_cluster: builtins.str
    def __init__(
        self,
        *,
        proxy_runtime: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        access_key: global___AwsEcsConfig.AccessKey | None = ...,
        region: builtins.str = ...,
        ecs_cluster: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["access_key", b"access_key", "credentials", b"credentials", "proxy_runtime", b"proxy_runtime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key", b"access_key", "credentials", b"credentials", "ecs_cluster", b"ecs_cluster", "proxy_runtime", b"proxy_runtime", "region", b"region"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["credentials", b"credentials"]) -> typing_extensions.Literal["access_key"] | None: ...

global___AwsEcsConfig = AwsEcsConfig

class GoogleCloudRunConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROXY_RUNTIME_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_JSON_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    @property
    def proxy_runtime(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    @property
    def service_account_json(self) -> prodvana.proto.prodvana.common_config.env_pb2.SecretReferenceValue:
        """TODO(naphat) support for job service account name"""
    project: builtins.str
    region: builtins.str
    """next tag: 5"""
    def __init__(
        self,
        *,
        proxy_runtime: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        service_account_json: prodvana.proto.prodvana.common_config.env_pb2.SecretReferenceValue | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "proxy_runtime", b"proxy_runtime", "service_account_json", b"service_account_json"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "project", b"project", "proxy_runtime", b"proxy_runtime", "region", b"region", "service_account_json", b"service_account_json"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["credentials", b"credentials"]) -> typing_extensions.Literal["service_account_json"] | None: ...

global___GoogleCloudRunConfig = GoogleCloudRunConfig

class ClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _CloudProvider:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CloudProviderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClusterConfig._CloudProvider.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: ClusterConfig._CloudProvider.ValueType  # 0
        EKS: ClusterConfig._CloudProvider.ValueType  # 1
        GKE: ClusterConfig._CloudProvider.ValueType  # 2
        AKS: ClusterConfig._CloudProvider.ValueType  # 3
        ONPREM: ClusterConfig._CloudProvider.ValueType  # 4
        OTHER_CLOUD: ClusterConfig._CloudProvider.ValueType  # 5

    class CloudProvider(_CloudProvider, metaclass=_CloudProviderEnumTypeWrapper): ...
    UNKNOWN: ClusterConfig.CloudProvider.ValueType  # 0
    EKS: ClusterConfig.CloudProvider.ValueType  # 1
    GKE: ClusterConfig.CloudProvider.ValueType  # 2
    AKS: ClusterConfig.CloudProvider.ValueType  # 3
    ONPREM: ClusterConfig.CloudProvider.ValueType  # 4
    OTHER_CLOUD: ClusterConfig.CloudProvider.ValueType  # 5

    class Kubecost(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        KUBECOST_NAMESPACE_FIELD_NUMBER: builtins.int
        MANAGED_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        kubecost_namespace: builtins.str
        managed: builtins.bool
        """deprecated"""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            kubecost_namespace: builtins.str = ...,
            managed: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "kubecost_namespace", b"kubecost_namespace", "managed", b"managed"]) -> None: ...

    class Datadog(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        DATADOG_NAMESPACE_FIELD_NUMBER: builtins.int
        API_KEY_FIELD_NUMBER: builtins.int
        SITE_FIELD_NUMBER: builtins.int
        MANAGED_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        datadog_namespace: builtins.str
        api_key: builtins.str
        site: builtins.str
        managed: builtins.bool
        """deprecated"""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            datadog_namespace: builtins.str = ...,
            api_key: builtins.str = ...,
            site: builtins.str = ...,
            managed: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key", "datadog_namespace", b"datadog_namespace", "enabled", b"enabled", "managed", b"managed", "site", b"site"]) -> None: ...

    class ALBIngress(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        INGRESS_CLASS_FIELD_NUMBER: builtins.int
        DEFAULT_BALANCER_ATTRIBUTES_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        ingress_class: builtins.str
        @property
        def default_balancer_attributes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Attributes from https://docs.aws.amazon.com/elasticloadbalancing/latest/application/application-load-balancers.html#load-balancer-attributes
            that are added to all Ingresses/LBs created in this runtime.
            """
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            ingress_class: builtins.str = ...,
            default_balancer_attributes: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["default_balancer_attributes", b"default_balancer_attributes", "enabled", b"enabled", "ingress_class", b"ingress_class"]) -> None: ...

    class ArgoRollouts(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class AnalysisTemplate(google.protobuf.message.Message):
            """deprecated"""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _ArgValue:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _ArgValueEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClusterConfig.ArgoRollouts.AnalysisTemplate._ArgValue.ValueType], builtins.type):  # noqa: F821
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                UNKNOWN: ClusterConfig.ArgoRollouts.AnalysisTemplate._ArgValue.ValueType  # 0
                SERVICE: ClusterConfig.ArgoRollouts.AnalysisTemplate._ArgValue.ValueType  # 1
                RELEASE_CHANNEL: ClusterConfig.ArgoRollouts.AnalysisTemplate._ArgValue.ValueType  # 2

            class ArgValue(_ArgValue, metaclass=_ArgValueEnumTypeWrapper): ...
            UNKNOWN: ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType  # 0
            SERVICE: ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType  # 1
            RELEASE_CHANNEL: ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType  # 2

            class ArgMappingEntry(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                KEY_FIELD_NUMBER: builtins.int
                VALUE_FIELD_NUMBER: builtins.int
                key: builtins.str
                value: global___ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType
                def __init__(
                    self,
                    *,
                    key: builtins.str = ...,
                    value: global___ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

            NAME_FIELD_NUMBER: builtins.int
            ARG_MAPPING_FIELD_NUMBER: builtins.int
            name: builtins.str
            @property
            def arg_mapping(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, global___ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType]:
                """template argument name to prodvana value to inject"""
            def __init__(
                self,
                *,
                name: builtins.str = ...,
                arg_mapping: collections.abc.Mapping[builtins.str, global___ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["arg_mapping", b"arg_mapping", "name", b"name"]) -> None: ...

        ENABLED_FIELD_NUMBER: builtins.int
        TEMPLATES_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        @property
        def templates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterConfig.ArgoRollouts.AnalysisTemplate]:
            """deprecated"""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            templates: collections.abc.Iterable[global___ClusterConfig.ArgoRollouts.AnalysisTemplate] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "templates", b"templates"]) -> None: ...

    class GKEIngress(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        CONTAINER_NATIVE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        container_native: builtins.bool
        """Enables container native load balancing, allowing GCP LBs to target k8s pods directly.
        See: https://cloud.google.com/kubernetes-engine/docs/how-to/container-native-load-balancing
        """
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            container_native: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["container_native", b"container_native", "enabled", b"enabled"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    KUBECOST_FIELD_NUMBER: builtins.int
    DATADOG_FIELD_NUMBER: builtins.int
    ALB_INGRESS_FIELD_NUMBER: builtins.int
    ARGO_ROLLOUTS_FIELD_NUMBER: builtins.int
    GKE_INGRESS_FIELD_NUMBER: builtins.int
    SELF_MANAGED_GKE_INGRESS_FIELD_NUMBER: builtins.int
    CLOUD_PROVIDER_FIELD_NUMBER: builtins.int
    DETECTED_CLUSTER_METADATA_FIELD_NUMBER: builtins.int
    USER_SUPPLIED_CLUSTER_METADATA_FIELD_NUMBER: builtins.int
    FAKE_FIELD_NUMBER: builtins.int
    EXTENSION_FIELD_NUMBER: builtins.int
    TERRAFORM_RUNNER_FIELD_NUMBER: builtins.int
    PULUMI_RUNNER_FIELD_NUMBER: builtins.int
    AWS_ECS_FIELD_NUMBER: builtins.int
    GOOGLE_CLOUD_RUN_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    AUTO_ROLLBACK_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def kubecost(self) -> global___ClusterConfig.Kubecost: ...
    @property
    def datadog(self) -> global___ClusterConfig.Datadog: ...
    @property
    def alb_ingress(self) -> global___ClusterConfig.ALBIngress: ...
    @property
    def argo_rollouts(self) -> global___ClusterConfig.ArgoRollouts: ...
    @property
    def gke_ingress(self) -> global___ClusterConfig.GKEIngress: ...
    @property
    def self_managed_gke_ingress(self) -> global___ClusterConfig.GKEIngress:
        """Self-Managed GKE Ingress - exposes configuration options for GKE Ingress
        but does not create an ingress object for you
        """
    cloud_provider: global___ClusterConfig.CloudProvider.ValueType
    @property
    def detected_cluster_metadata(self) -> global___ClusterMetadata: ...
    @property
    def user_supplied_cluster_metadata(self) -> global___ClusterMetadata: ...
    @property
    def fake(self) -> global___FakeClusterConfig:
        """only used for fake runtimes"""
    @property
    def extension(self) -> global___ExtensionClusterConfig: ...
    @property
    def terraform_runner(self) -> global___TerraformRunnerConfig:
        """terraform runner is a runtime that runs terraform via k8s jobs"""
    @property
    def pulumi_runner(self) -> global___TerraformRunnerConfig:
        """pulumi runner is a runtime that runs pulumi via k8s jobs"""
    @property
    def aws_ecs(self) -> global___AwsEcsConfig: ...
    @property
    def google_cloud_run(self) -> global___GoogleCloudRunConfig: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.labels.labels_pb2.LabelDefinition]: ...
    @property
    def auto_rollback(self) -> prodvana.proto.prodvana.common_config.rollback_pb2.AutoRollbackConfig: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        kubecost: global___ClusterConfig.Kubecost | None = ...,
        datadog: global___ClusterConfig.Datadog | None = ...,
        alb_ingress: global___ClusterConfig.ALBIngress | None = ...,
        argo_rollouts: global___ClusterConfig.ArgoRollouts | None = ...,
        gke_ingress: global___ClusterConfig.GKEIngress | None = ...,
        self_managed_gke_ingress: global___ClusterConfig.GKEIngress | None = ...,
        cloud_provider: global___ClusterConfig.CloudProvider.ValueType = ...,
        detected_cluster_metadata: global___ClusterMetadata | None = ...,
        user_supplied_cluster_metadata: global___ClusterMetadata | None = ...,
        fake: global___FakeClusterConfig | None = ...,
        extension: global___ExtensionClusterConfig | None = ...,
        terraform_runner: global___TerraformRunnerConfig | None = ...,
        pulumi_runner: global___TerraformRunnerConfig | None = ...,
        aws_ecs: global___AwsEcsConfig | None = ...,
        google_cloud_run: global___GoogleCloudRunConfig | None = ...,
        labels: collections.abc.Iterable[prodvana.proto.prodvana.labels.labels_pb2.LabelDefinition] | None = ...,
        auto_rollback: prodvana.proto.prodvana.common_config.rollback_pb2.AutoRollbackConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alb_ingress", b"alb_ingress", "argo_rollouts", b"argo_rollouts", "auto_rollback", b"auto_rollback", "aws_ecs", b"aws_ecs", "cluster_oneof", b"cluster_oneof", "datadog", b"datadog", "detected_cluster_metadata", b"detected_cluster_metadata", "extension", b"extension", "fake", b"fake", "gke_ingress", b"gke_ingress", "google_cloud_run", b"google_cloud_run", "kubecost", b"kubecost", "pulumi_runner", b"pulumi_runner", "self_managed_gke_ingress", b"self_managed_gke_ingress", "terraform_runner", b"terraform_runner", "user_supplied_cluster_metadata", b"user_supplied_cluster_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alb_ingress", b"alb_ingress", "argo_rollouts", b"argo_rollouts", "auto_rollback", b"auto_rollback", "aws_ecs", b"aws_ecs", "cloud_provider", b"cloud_provider", "cluster_oneof", b"cluster_oneof", "datadog", b"datadog", "detected_cluster_metadata", b"detected_cluster_metadata", "extension", b"extension", "fake", b"fake", "gke_ingress", b"gke_ingress", "google_cloud_run", b"google_cloud_run", "kubecost", b"kubecost", "labels", b"labels", "name", b"name", "pulumi_runner", b"pulumi_runner", "self_managed_gke_ingress", b"self_managed_gke_ingress", "terraform_runner", b"terraform_runner", "user_supplied_cluster_metadata", b"user_supplied_cluster_metadata"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["cluster_oneof", b"cluster_oneof"]) -> typing_extensions.Literal["fake", "extension", "terraform_runner", "pulumi_runner", "aws_ecs", "google_cloud_run"] | None: ...

global___ClusterConfig = ClusterConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.settings.organization.users_pb2

class UsersSettingsManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetUser: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.settings.organization.users_pb2.GetUserReq,
        prodvana.proto.prodvana.settings.organization.users_pb2.GetUserResp,
    ]
    ListUsers: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.settings.organization.users_pb2.ListUsersReq,
        prodvana.proto.prodvana.settings.organization.users_pb2.ListUsersResp,
    ]
    ListRoles: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.settings.organization.users_pb2.ListRolesReq,
        prodvana.proto.prodvana.settings.organization.users_pb2.ListRolesResp,
    ]
    SetRoles: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.settings.organization.users_pb2.SetRolesReq,
        prodvana.proto.prodvana.settings.organization.users_pb2.SetRolesResp,
    ]
    InviteUsers: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.settings.organization.users_pb2.InviteUsersReq,
        prodvana.proto.prodvana.settings.organization.users_pb2.InviteUsersResp,
    ]
    OrganizationSupportsInvites: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.settings.organization.users_pb2.OrganizationSupportsInvitesReq,
        prodvana.proto.prodvana.settings.organization.users_pb2.OrganizationSupportsInvitesResp,
    ]
    RemoveUser: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.settings.organization.users_pb2.RemoveUserReq,
        prodvana.proto.prodvana.settings.organization.users_pb2.RemoveUserResp,
    ]

class UsersSettingsManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetUser(
        self,
        request: prodvana.proto.prodvana.settings.organization.users_pb2.GetUserReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.settings.organization.users_pb2.GetUserResp: ...
    @abc.abstractmethod
    def ListUsers(
        self,
        request: prodvana.proto.prodvana.settings.organization.users_pb2.ListUsersReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.settings.organization.users_pb2.ListUsersResp: ...
    @abc.abstractmethod
    def ListRoles(
        self,
        request: prodvana.proto.prodvana.settings.organization.users_pb2.ListRolesReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.settings.organization.users_pb2.ListRolesResp: ...
    @abc.abstractmethod
    def SetRoles(
        self,
        request: prodvana.proto.prodvana.settings.organization.users_pb2.SetRolesReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.settings.organization.users_pb2.SetRolesResp: ...
    @abc.abstractmethod
    def InviteUsers(
        self,
        request: prodvana.proto.prodvana.settings.organization.users_pb2.InviteUsersReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.settings.organization.users_pb2.InviteUsersResp: ...
    @abc.abstractmethod
    def OrganizationSupportsInvites(
        self,
        request: prodvana.proto.prodvana.settings.organization.users_pb2.OrganizationSupportsInvitesReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.settings.organization.users_pb2.OrganizationSupportsInvitesResp: ...
    @abc.abstractmethod
    def RemoveUser(
        self,
        request: prodvana.proto.prodvana.settings.organization.users_pb2.RemoveUserReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.settings.organization.users_pb2.RemoveUserResp: ...

def add_UsersSettingsManagerServicer_to_server(servicer: UsersSettingsManagerServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import grpc
import prodvana.proto.prodvana.managed_resource.manager_pb2

class ResourceManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ConfigureK8sCluster: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.managed_resource.manager_pb2.ConfigureK8sClusterReq,
        prodvana.proto.prodvana.managed_resource.manager_pb2.ConfigureK8sClusterResp,
    ]
    GetManagedResource: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.managed_resource.manager_pb2.GetManagedResourceReq,
        prodvana.proto.prodvana.managed_resource.manager_pb2.GetManagedResourceResp,
    ]
    ListManagedResources: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.managed_resource.manager_pb2.ListManagedResourcesReq,
        prodvana.proto.prodvana.managed_resource.manager_pb2.ListManagedResourcesResp,
    ]
    GetArchive: grpc.UnaryStreamMultiCallable[
        prodvana.proto.prodvana.managed_resource.manager_pb2.GetArchiveReq,
        prodvana.proto.prodvana.managed_resource.manager_pb2.GetArchiveResp,
    ]
    DeleteManagedResource: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.managed_resource.manager_pb2.DeleteManagedResourceReq,
        prodvana.proto.prodvana.managed_resource.manager_pb2.DeleteManagedResourceResp,
    ]
    MarkRunDone: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.managed_resource.manager_pb2.MarkRunDoneReq,
        prodvana.proto.prodvana.managed_resource.manager_pb2.MarkRunDoneResp,
    ]
    """TODO(naphat) delete this endpoint once we automate pulumi runs"""

class ResourceManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ConfigureK8sCluster(
        self,
        request: prodvana.proto.prodvana.managed_resource.manager_pb2.ConfigureK8sClusterReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.managed_resource.manager_pb2.ConfigureK8sClusterResp: ...
    @abc.abstractmethod
    def GetManagedResource(
        self,
        request: prodvana.proto.prodvana.managed_resource.manager_pb2.GetManagedResourceReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.managed_resource.manager_pb2.GetManagedResourceResp: ...
    @abc.abstractmethod
    def ListManagedResources(
        self,
        request: prodvana.proto.prodvana.managed_resource.manager_pb2.ListManagedResourcesReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.managed_resource.manager_pb2.ListManagedResourcesResp: ...
    @abc.abstractmethod
    def GetArchive(
        self,
        request: prodvana.proto.prodvana.managed_resource.manager_pb2.GetArchiveReq,
        context: grpc.ServicerContext,
    ) -> collections.abc.Iterator[prodvana.proto.prodvana.managed_resource.manager_pb2.GetArchiveResp]: ...
    @abc.abstractmethod
    def DeleteManagedResource(
        self,
        request: prodvana.proto.prodvana.managed_resource.manager_pb2.DeleteManagedResourceReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.managed_resource.manager_pb2.DeleteManagedResourceResp: ...
    @abc.abstractmethod
    def MarkRunDone(
        self,
        request: prodvana.proto.prodvana.managed_resource.manager_pb2.MarkRunDoneReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.managed_resource.manager_pb2.MarkRunDoneResp:
        """TODO(naphat) delete this endpoint once we automate pulumi runs"""

def add_ResourceManagerServicer_to_server(servicer: ResourceManagerServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ImpactCategory:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ImpactCategoryEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ImpactCategory.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_CATEGORY: _ImpactCategory.ValueType  # 0
    BACKEND: _ImpactCategory.ValueType  # 1
    FRONTEND: _ImpactCategory.ValueType  # 2
    DATA_INTEGRITY: _ImpactCategory.ValueType  # 3
    SECURITY: _ImpactCategory.ValueType  # 4
    COST: _ImpactCategory.ValueType  # 5
    PRODVANA_INTERNAL_ERROR: _ImpactCategory.ValueType  # 6
    """Prodvana is having trouble determining the impact of this commit"""

class ImpactCategory(_ImpactCategory, metaclass=_ImpactCategoryEnumTypeWrapper): ...

UNKNOWN_CATEGORY: ImpactCategory.ValueType  # 0
BACKEND: ImpactCategory.ValueType  # 1
FRONTEND: ImpactCategory.ValueType  # 2
DATA_INTEGRITY: ImpactCategory.ValueType  # 3
SECURITY: ImpactCategory.ValueType  # 4
COST: ImpactCategory.ValueType  # 5
PRODVANA_INTERNAL_ERROR: ImpactCategory.ValueType  # 6
"""Prodvana is having trouble determining the impact of this commit"""
global___ImpactCategory = ImpactCategory

class _IncidentType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _IncidentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IncidentType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_INCIDENT: _IncidentType.ValueType  # 0
    OUTAGE: _IncidentType.ValueType  # 1
    EXPENSE: _IncidentType.ValueType  # 2
    SECURITY_BREACH: _IncidentType.ValueType  # 3
    USER_ISSUE: _IncidentType.ValueType  # 4

class IncidentType(_IncidentType, metaclass=_IncidentTypeEnumTypeWrapper): ...

UNKNOWN_INCIDENT: IncidentType.ValueType  # 0
OUTAGE: IncidentType.ValueType  # 1
EXPENSE: IncidentType.ValueType  # 2
SECURITY_BREACH: IncidentType.ValueType  # 3
USER_ISSUE: IncidentType.ValueType  # 4
global___IncidentType = IncidentType

class ImpactAnalysisResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATEGORY_FIELD_NUMBER: builtins.int
    INCIDENT_TYPE_FIELD_NUMBER: builtins.int
    IMPACT_SCORE_FIELD_NUMBER: builtins.int
    IMPACT_REASONING_FIELD_NUMBER: builtins.int
    LIKELIHOOD_SCORE_FIELD_NUMBER: builtins.int
    LIKELIHOOD_REASONING_FIELD_NUMBER: builtins.int
    OVERALL_SCORE_FIELD_NUMBER: builtins.int
    category: global___ImpactCategory.ValueType
    incident_type: global___IncidentType.ValueType
    impact_score: builtins.float
    impact_reasoning: builtins.str
    likelihood_score: builtins.float
    likelihood_reasoning: builtins.str
    overall_score: builtins.float
    def __init__(
        self,
        *,
        category: global___ImpactCategory.ValueType = ...,
        incident_type: global___IncidentType.ValueType = ...,
        impact_score: builtins.float = ...,
        impact_reasoning: builtins.str = ...,
        likelihood_score: builtins.float = ...,
        likelihood_reasoning: builtins.str = ...,
        overall_score: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["category", b"category", "impact_reasoning", b"impact_reasoning", "impact_score", b"impact_score", "incident_type", b"incident_type", "likelihood_reasoning", b"likelihood_reasoning", "likelihood_score", b"likelihood_score", "overall_score", b"overall_score"]) -> None: ...

global___ImpactAnalysisResult = ImpactAnalysisResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetInfoOutput(google.protobuf.message.Message):
    """output format for the get_info command, in json format"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OutputContent]: ...
    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[global___OutputContent] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["outputs", b"outputs"]) -> None: ...

global___GetInfoOutput = GetInfoOutput

class OutputContent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    name: builtins.str
    text: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "text", b"text"]) -> None: ...

global___OutputContent = OutputContent



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.service import service_manager_pb2 as prodvana_dot_service_dot_service__manager__pb2


class ServiceManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ConfigureService = channel.unary_unary(
                '/prodvana.service.ServiceManager/ConfigureService',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.ConfigureServiceReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.ConfigureServiceResp.FromString,
                )
        self.ValidateConfigureService = channel.unary_unary(
                '/prodvana.service.ServiceManager/ValidateConfigureService',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.ConfigureServiceReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.ValidateConfigureServiceResp.FromString,
                )
        self.ListServiceConfigVersions = channel.unary_unary(
                '/prodvana.service.ServiceManager/ListServiceConfigVersions',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.ListServiceConfigVersionsReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.ListServiceConfigVersionsResp.FromString,
                )
        self.GetServiceConfig = channel.unary_unary(
                '/prodvana.service.ServiceManager/GetServiceConfig',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceConfigReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceConfigResp.FromString,
                )
        self.GenerateVersionName = channel.unary_unary(
                '/prodvana.service.ServiceManager/GenerateVersionName',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.GenerateVersionNameReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.GenerateVersionNameResp.FromString,
                )
        self.ApplyParameters = channel.unary_unary(
                '/prodvana.service.ServiceManager/ApplyParameters',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.ApplyParametersReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.ApplyParametersResp.FromString,
                )
        self.ValidateApplyParameters = channel.unary_unary(
                '/prodvana.service.ServiceManager/ValidateApplyParameters',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.ApplyParametersReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.ValidateApplyParametersResp.FromString,
                )
        self.GetMaterializedConfig = channel.unary_unary(
                '/prodvana.service.ServiceManager/GetMaterializedConfig',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.GetMaterializedConfigReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.GetMaterializedConfigResp.FromString,
                )
        self.ListMaterializedConfigVersions = channel.unary_unary(
                '/prodvana.service.ServiceManager/ListMaterializedConfigVersions',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.ListMaterializedConfigVersionsReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.ListMaterializedConfigVersionsResp.FromString,
                )
        self.DeleteService = channel.unary_unary(
                '/prodvana.service.ServiceManager/DeleteService',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.DeleteServiceReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.DeleteServiceResp.FromString,
                )
        self.ListServices = channel.unary_unary(
                '/prodvana.service.ServiceManager/ListServices',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.ListServicesReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.ListServicesResp.FromString,
                )
        self.ListCommits = channel.unary_unary(
                '/prodvana.service.ServiceManager/ListCommits',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.ListCommitsReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.ListCommitsResp.FromString,
                )
        self.GetService = channel.unary_unary(
                '/prodvana.service.ServiceManager/GetService',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceResp.FromString,
                )
        self.ListServiceInstances = channel.unary_unary(
                '/prodvana.service.ServiceManager/ListServiceInstances',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.ListServiceInstancesReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.ListServiceInstancesResp.FromString,
                )
        self.GetServiceInstance = channel.unary_unary(
                '/prodvana.service.ServiceManager/GetServiceInstance',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceInstanceReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceInstanceResp.FromString,
                )
        self.GetServiceMetrics = channel.unary_unary(
                '/prodvana.service.ServiceManager/GetServiceMetrics',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceMetricsReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceMetricsResp.FromString,
                )
        self.GetServiceInsights = channel.unary_unary(
                '/prodvana.service.ServiceManager/GetServiceInsights',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceInsightsReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceInsightsResp.FromString,
                )
        self.SnoozeServiceInsight = channel.unary_unary(
                '/prodvana.service.ServiceManager/SnoozeServiceInsight',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.SnoozeServiceInsightReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.SnoozeServiceInsightResp.FromString,
                )
        self.GetServiceMetadata = channel.unary_unary(
                '/prodvana.service.ServiceManager/GetServiceMetadata',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceMetadataReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceMetadataResp.FromString,
                )
        self.SetServiceMetadata = channel.unary_unary(
                '/prodvana.service.ServiceManager/SetServiceMetadata',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.SetServiceMetadataReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.SetServiceMetadataResp.FromString,
                )
        self.SetServiceConvergenceMode = channel.unary_unary(
                '/prodvana.service.ServiceManager/SetServiceConvergenceMode',
                request_serializer=prodvana_dot_service_dot_service__manager__pb2.SetServiceConvergenceModeReq.SerializeToString,
                response_deserializer=prodvana_dot_service_dot_service__manager__pb2.SetServiceConvergenceModeResp.FromString,
                )


class ServiceManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ConfigureService(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateConfigureService(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListServiceConfigVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceConfig(self, request, context):
        """unparametrized configs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateVersionName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyParameters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateApplyParameters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMaterializedConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMaterializedConfigVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteService(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListServices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCommits(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetService(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListServiceInstances(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceInstance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceMetrics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceInsights(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SnoozeServiceInsight(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetServiceMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetServiceConvergenceMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ServiceManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ConfigureService': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureService,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.ConfigureServiceReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.ConfigureServiceResp.SerializeToString,
            ),
            'ValidateConfigureService': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateConfigureService,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.ConfigureServiceReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.ValidateConfigureServiceResp.SerializeToString,
            ),
            'ListServiceConfigVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListServiceConfigVersions,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.ListServiceConfigVersionsReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.ListServiceConfigVersionsResp.SerializeToString,
            ),
            'GetServiceConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceConfig,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceConfigReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceConfigResp.SerializeToString,
            ),
            'GenerateVersionName': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateVersionName,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.GenerateVersionNameReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.GenerateVersionNameResp.SerializeToString,
            ),
            'ApplyParameters': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyParameters,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.ApplyParametersReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.ApplyParametersResp.SerializeToString,
            ),
            'ValidateApplyParameters': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateApplyParameters,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.ApplyParametersReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.ValidateApplyParametersResp.SerializeToString,
            ),
            'GetMaterializedConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMaterializedConfig,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.GetMaterializedConfigReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.GetMaterializedConfigResp.SerializeToString,
            ),
            'ListMaterializedConfigVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMaterializedConfigVersions,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.ListMaterializedConfigVersionsReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.ListMaterializedConfigVersionsResp.SerializeToString,
            ),
            'DeleteService': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteService,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.DeleteServiceReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.DeleteServiceResp.SerializeToString,
            ),
            'ListServices': grpc.unary_unary_rpc_method_handler(
                    servicer.ListServices,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.ListServicesReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.ListServicesResp.SerializeToString,
            ),
            'ListCommits': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCommits,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.ListCommitsReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.ListCommitsResp.SerializeToString,
            ),
            'GetService': grpc.unary_unary_rpc_method_handler(
                    servicer.GetService,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceResp.SerializeToString,
            ),
            'ListServiceInstances': grpc.unary_unary_rpc_method_handler(
                    servicer.ListServiceInstances,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.ListServiceInstancesReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.ListServiceInstancesResp.SerializeToString,
            ),
            'GetServiceInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceInstance,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceInstanceReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceInstanceResp.SerializeToString,
            ),
            'GetServiceMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceMetrics,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceMetricsReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceMetricsResp.SerializeToString,
            ),
            'GetServiceInsights': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceInsights,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceInsightsReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceInsightsResp.SerializeToString,
            ),
            'SnoozeServiceInsight': grpc.unary_unary_rpc_method_handler(
                    servicer.SnoozeServiceInsight,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.SnoozeServiceInsightReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.SnoozeServiceInsightResp.SerializeToString,
            ),
            'GetServiceMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceMetadata,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceMetadataReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.GetServiceMetadataResp.SerializeToString,
            ),
            'SetServiceMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.SetServiceMetadata,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.SetServiceMetadataReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.SetServiceMetadataResp.SerializeToString,
            ),
            'SetServiceConvergenceMode': grpc.unary_unary_rpc_method_handler(
                    servicer.SetServiceConvergenceMode,
                    request_deserializer=prodvana_dot_service_dot_service__manager__pb2.SetServiceConvergenceModeReq.FromString,
                    response_serializer=prodvana_dot_service_dot_service__manager__pb2.SetServiceConvergenceModeResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.service.ServiceManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ServiceManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ConfigureService(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/ConfigureService',
            prodvana_dot_service_dot_service__manager__pb2.ConfigureServiceReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.ConfigureServiceResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateConfigureService(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/ValidateConfigureService',
            prodvana_dot_service_dot_service__manager__pb2.ConfigureServiceReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.ValidateConfigureServiceResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListServiceConfigVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/ListServiceConfigVersions',
            prodvana_dot_service_dot_service__manager__pb2.ListServiceConfigVersionsReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.ListServiceConfigVersionsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/GetServiceConfig',
            prodvana_dot_service_dot_service__manager__pb2.GetServiceConfigReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.GetServiceConfigResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateVersionName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/GenerateVersionName',
            prodvana_dot_service_dot_service__manager__pb2.GenerateVersionNameReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.GenerateVersionNameResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyParameters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/ApplyParameters',
            prodvana_dot_service_dot_service__manager__pb2.ApplyParametersReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.ApplyParametersResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateApplyParameters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/ValidateApplyParameters',
            prodvana_dot_service_dot_service__manager__pb2.ApplyParametersReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.ValidateApplyParametersResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMaterializedConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/GetMaterializedConfig',
            prodvana_dot_service_dot_service__manager__pb2.GetMaterializedConfigReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.GetMaterializedConfigResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListMaterializedConfigVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/ListMaterializedConfigVersions',
            prodvana_dot_service_dot_service__manager__pb2.ListMaterializedConfigVersionsReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.ListMaterializedConfigVersionsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteService(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/DeleteService',
            prodvana_dot_service_dot_service__manager__pb2.DeleteServiceReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.DeleteServiceResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListServices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/ListServices',
            prodvana_dot_service_dot_service__manager__pb2.ListServicesReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.ListServicesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCommits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/ListCommits',
            prodvana_dot_service_dot_service__manager__pb2.ListCommitsReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.ListCommitsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetService(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/GetService',
            prodvana_dot_service_dot_service__manager__pb2.GetServiceReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.GetServiceResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListServiceInstances(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/ListServiceInstances',
            prodvana_dot_service_dot_service__manager__pb2.ListServiceInstancesReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.ListServiceInstancesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/GetServiceInstance',
            prodvana_dot_service_dot_service__manager__pb2.GetServiceInstanceReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.GetServiceInstanceResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/GetServiceMetrics',
            prodvana_dot_service_dot_service__manager__pb2.GetServiceMetricsReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.GetServiceMetricsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceInsights(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/GetServiceInsights',
            prodvana_dot_service_dot_service__manager__pb2.GetServiceInsightsReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.GetServiceInsightsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SnoozeServiceInsight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/SnoozeServiceInsight',
            prodvana_dot_service_dot_service__manager__pb2.SnoozeServiceInsightReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.SnoozeServiceInsightResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/GetServiceMetadata',
            prodvana_dot_service_dot_service__manager__pb2.GetServiceMetadataReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.GetServiceMetadataResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetServiceMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/SetServiceMetadata',
            prodvana_dot_service_dot_service__manager__pb2.SetServiceMetadataReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.SetServiceMetadataResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetServiceConvergenceMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.service.ServiceManager/SetServiceConvergenceMode',
            prodvana_dot_service_dot_service__manager__pb2.SetServiceConvergenceModeReq.SerializeToString,
            prodvana_dot_service_dot_service__manager__pb2.SetServiceConvergenceModeResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import os
from typing import Callable

from prodvana.client import Client
from prodvana.proto.prodvana.service.service_config_pb2 import (
    CompiledServiceInstanceConfig,
)
from prodvana.proto.prodvana.service.service_manager_pb2 import GetServiceInstanceReq


class InjectedVariables:
    PVN_APPLICATION = "PVN_APPLICATION"
    PVN_RELEASE_CHANNEL = "PVN_RELEASE_CHANNEL"
    PVN_SERVICE = "PVN_SERVICE"


def must_get_env(key: str, msg: str) -> str:
    val = os.getenv(key)
    assert val, f"{key} not set. {msg}"
    return val


def service_config_protection(
    client: Client, check: Callable[[CompiledServiceInstanceConfig], None]
) -> None:
    """
    A protection that is meant to run at the service or convergence level.
    `check` is a function that should throw an exception if there is something wrong with the service configuration.
    At the service level, check is called with the current service configuration.
    At the convergence level, check is called with each unique incoming service configuration.
    """
    # TODO(naphat) support convergence protections
    app = must_get_env(
        InjectedVariables.PVN_APPLICATION,
        "Only service-instance-level protections are supported",
    )
    rc = must_get_env(
        InjectedVariables.PVN_RELEASE_CHANNEL,
        "Only service-instance-level protections are supported",
    )
    svc = must_get_env(
        InjectedVariables.PVN_SERVICE,
        "Only service-instance-level protections are supported",
    )
    resp = client.service_manager.GetServiceInstance(
        GetServiceInstanceReq(
            application=app,
            release_channel=rc,
            service=svc,
        )
    )
    check(resp.service_instance.config)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/protection/protection_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import task_pb2 as prodvana_dot_common__config_dot_task__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.prodvana.common_config import kubernetes_config_pb2 as prodvana_dot_common__config_dot_kubernetes__config__pb2
from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2
from prodvana.proto.prodvana.runtimes import runtimes_config_pb2 as prodvana_dot_runtimes_dot_runtimes__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+prodvana/protection/protection_config.proto\x12\x13prodvana.protection\x1a\x1egoogle/protobuf/duration.proto\x1a\x17validate/validate.proto\x1a!prodvana/common_config/task.proto\x1a prodvana/common_config/env.proto\x1a.prodvana/common_config/kubernetes_config.proto\x1a\'prodvana/common_config/parameters.proto\x1a\'prodvana/runtimes/runtimes_config.proto\"\xc5\x04\n\x10ProtectionConfig\x12\x39\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12\x39\n\x0btask_config\x18\x02 \x01(\x0b\x32\".prodvana.common_config.TaskConfigH\x00\x12\x45\n\x11kubernetes_config\x18\x03 \x01(\x0b\x32(.prodvana.common_config.KubernetesConfigH\x00\x12\x30\n\rpoll_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12*\n\x07timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12N\n\nparameters\x18\x06 \x03(\x0b\x32+.prodvana.common_config.ParameterDefinitionB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12\x64\n\x03\x65nv\x18\x07 \x03(\x0b\x32..prodvana.protection.ProtectionConfig.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\x42\x12\n\x0b\x65xec_config\x12\x03\xf8\x42\x01\"\xe8\x03\n\"CompiledProtectionAttachmentConfig\x12\x35\n\x06\x63onfig\x18\x01 \x01(\x0b\x32%.prodvana.protection.ProtectionConfig\x12=\n\nattachment\x18\x02 \x01(\x0b\x32).prodvana.protection.ProtectionAttachment\x12\x44\n\x11runtime_execution\x18\x03 \x01(\x0b\x32).prodvana.runtimes.RuntimeExecutionConfig\x12v\n\x03\x65nv\x18\x04 \x03(\x0b\x32@.prodvana.protection.CompiledProtectionAttachmentConfig.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12@\n\x10parameter_values\x18\x05 \x03(\x0b\x32&.prodvana.common_config.ParameterValue\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\"Z\n\x19ServiceInstanceAttachment\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x17\n\x0frelease_channel\x18\x02 \x01(\t\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\t\"H\n\x18ReleaseChannelAttachment\x12\x13\n\x0b\x61pplication\x18\x01 \x01(\t\x12\x17\n\x0frelease_channel\x18\x02 \x01(\t\"1\n\x15\x43onvergenceAttachment\x12\x18\n\x10\x64\x65sired_state_id\x18\x01 \x01(\t\"\x82\x02\n\x14ProtectionAttachment\x12J\n\x10service_instance\x18\x01 \x01(\x0b\x32..prodvana.protection.ServiceInstanceAttachmentH\x00\x12H\n\x0frelease_channel\x18\x02 \x01(\x0b\x32-.prodvana.protection.ReleaseChannelAttachmentH\x00\x12\x41\n\x0b\x63onvergence\x18\x03 \x01(\x0b\x32*.prodvana.protection.ConvergenceAttachmentH\x00\x42\x11\n\nattachment\x12\x03\xf8\x42\x01\x42OZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.protection.protection_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protection'
  _PROTECTIONCONFIG_ENVENTRY._options = None
  _PROTECTIONCONFIG_ENVENTRY._serialized_options = b'8\001'
  _PROTECTIONCONFIG.oneofs_by_name['exec_config']._options = None
  _PROTECTIONCONFIG.oneofs_by_name['exec_config']._serialized_options = b'\370B\001'
  _PROTECTIONCONFIG.fields_by_name['name']._options = None
  _PROTECTIONCONFIG.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _PROTECTIONCONFIG.fields_by_name['parameters']._options = None
  _PROTECTIONCONFIG.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _PROTECTIONCONFIG.fields_by_name['env']._options = None
  _PROTECTIONCONFIG.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _COMPILEDPROTECTIONATTACHMENTCONFIG_ENVENTRY._options = None
  _COMPILEDPROTECTIONATTACHMENTCONFIG_ENVENTRY._serialized_options = b'8\001'
  _COMPILEDPROTECTIONATTACHMENTCONFIG.fields_by_name['env']._options = None
  _COMPILEDPROTECTIONATTACHMENTCONFIG.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _PROTECTIONATTACHMENT.oneofs_by_name['attachment']._options = None
  _PROTECTIONATTACHMENT.oneofs_by_name['attachment']._serialized_options = b'\370B\001'
  _globals['_PROTECTIONCONFIG']._serialized_start=325
  _globals['_PROTECTIONCONFIG']._serialized_end=906
  _globals['_PROTECTIONCONFIG_ENVENTRY']._serialized_start=810
  _globals['_PROTECTIONCONFIG_ENVENTRY']._serialized_end=886
  _globals['_COMPILEDPROTECTIONATTACHMENTCONFIG']._serialized_start=909
  _globals['_COMPILEDPROTECTIONATTACHMENTCONFIG']._serialized_end=1397
  _globals['_COMPILEDPROTECTIONATTACHMENTCONFIG_ENVENTRY']._serialized_start=810
  _globals['_COMPILEDPROTECTIONATTACHMENTCONFIG_ENVENTRY']._serialized_end=886
  _globals['_SERVICEINSTANCEATTACHMENT']._serialized_start=1399
  _globals['_SERVICEINSTANCEATTACHMENT']._serialized_end=1489
  _globals['_RELEASECHANNELATTACHMENT']._serialized_start=1491
  _globals['_RELEASECHANNELATTACHMENT']._serialized_end=1563
  _globals['_CONVERGENCEATTACHMENT']._serialized_start=1565
  _globals['_CONVERGENCEATTACHMENT']._serialized_end=1614
  _globals['_PROTECTIONATTACHMENT']._serialized_start=1617
  _globals['_PROTECTIONATTACHMENT']._serialized_end=1875
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.common_config.env_pb2
import prodvana.proto.prodvana.common_config.kubernetes_config_pb2
import prodvana.proto.prodvana.common_config.parameters_pb2
import prodvana.proto.prodvana.common_config.task_pb2
import prodvana.proto.prodvana.runtimes.runtimes_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ProtectionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    TASK_CONFIG_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    POLL_INTERVAL_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def task_config(self) -> prodvana.proto.prodvana.common_config.task_pb2.TaskConfig:
        """Inline task config with retry, template support."""
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def poll_interval(self) -> google.protobuf.duration_pb2.Duration:
        """customize intervals instead of using Prodvana default
        how often to run check even if it succeeds
        """
    @property
    def timeout(self) -> google.protobuf.duration_pb2.Duration:
        """deprecated, not used"""
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition]: ...
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """optional env variables to inject and override from exec_config"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        task_config: prodvana.proto.prodvana.common_config.task_pb2.TaskConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        poll_interval: google.protobuf.duration_pb2.Duration | None = ...,
        timeout: google.protobuf.duration_pb2.Duration | None = ...,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition] | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "poll_interval", b"poll_interval", "task_config", b"task_config", "timeout", b"timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["env", b"env", "exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "name", b"name", "parameters", b"parameters", "poll_interval", b"poll_interval", "task_config", b"task_config", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["exec_config", b"exec_config"]) -> typing_extensions.Literal["task_config", "kubernetes_config"] | None: ...

global___ProtectionConfig = ProtectionConfig

class CompiledProtectionAttachmentConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONFIG_FIELD_NUMBER: builtins.int
    ATTACHMENT_FIELD_NUMBER: builtins.int
    RUNTIME_EXECUTION_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    PARAMETER_VALUES_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> global___ProtectionConfig: ...
    @property
    def attachment(self) -> global___ProtectionAttachment:
        """Protection source - where did this protection get attached from (service/app/org/...)?"""
    @property
    def runtime_execution(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """The compiled environment for this attachment's context, e.g.  Release Channel."""
    @property
    def parameter_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue]:
        """compiled parameter values"""
    def __init__(
        self,
        *,
        config: global___ProtectionConfig | None = ...,
        attachment: global___ProtectionAttachment | None = ...,
        runtime_execution: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        parameter_values: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attachment", b"attachment", "config", b"config", "runtime_execution", b"runtime_execution"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attachment", b"attachment", "config", b"config", "env", b"env", "parameter_values", b"parameter_values", "runtime_execution", b"runtime_execution"]) -> None: ...

global___CompiledProtectionAttachmentConfig = CompiledProtectionAttachmentConfig

class ServiceInstanceAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    service: builtins.str
    release_channel: builtins.str
    application: builtins.str
    def __init__(
        self,
        *,
        service: builtins.str = ...,
        release_channel: builtins.str = ...,
        application: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "release_channel", b"release_channel", "service", b"service"]) -> None: ...

global___ServiceInstanceAttachment = ServiceInstanceAttachment

class ReleaseChannelAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    application: builtins.str
    release_channel: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        release_channel: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "release_channel", b"release_channel"]) -> None: ...

global___ReleaseChannelAttachment = ReleaseChannelAttachment

class ConvergenceAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id"]) -> None: ...

global___ConvergenceAttachment = ConvergenceAttachment

class ProtectionAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_INSTANCE_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    CONVERGENCE_FIELD_NUMBER: builtins.int
    @property
    def service_instance(self) -> global___ServiceInstanceAttachment: ...
    @property
    def release_channel(self) -> global___ReleaseChannelAttachment: ...
    @property
    def convergence(self) -> global___ConvergenceAttachment: ...
    def __init__(
        self,
        *,
        service_instance: global___ServiceInstanceAttachment | None = ...,
        release_channel: global___ReleaseChannelAttachment | None = ...,
        convergence: global___ConvergenceAttachment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attachment", b"attachment", "convergence", b"convergence", "release_channel", b"release_channel", "service_instance", b"service_instance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attachment", b"attachment", "convergence", b"convergence", "release_channel", b"release_channel", "service_instance", b"service_instance"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["attachment", b"attachment"]) -> typing_extensions.Literal["service_instance", "release_channel", "convergence"] | None: ...

global___ProtectionAttachment = ProtectionAttachment
